EXPORTS
	??0CAutoTestManager@@AAE@PAVMAutoTestApp@@@Z @ 1 NONAME ; CAutoTestManager::CAutoTestManager(class MAutoTestApp *)
	__E32Dll @ 2 NONAME ABSENT ; CTestAppUi::CTestAppUi(class CTestStep *, class TDesC16 const &, int, int, int)
	__E32Dll @ 3 NONAME ABSENT ; CTestCoeAppUi::CTestCoeAppUi(class CTestStep *)
	??1CAutoTestManager@@UAE@XZ @ 4 NONAME ; CAutoTestManager::~CAutoTestManager(void)
	??1CTestAppUi@@UAE@XZ @ 5 NONAME ; CTestAppUi::~CTestAppUi(void)
	??1CTestCoeAppUi@@UAE@XZ @ 6 NONAME ; CTestCoeAppUi::~CTestCoeAppUi(void)
	?ConstructL@CTestAppUi@@UAEXXZ @ 7 NONAME ; void CTestAppUi::ConstructL(void)
	?ConstructL@CTestCoeAppUi@@QAEXXZ @ 8 NONAME ; void CTestCoeAppUi::ConstructL(void)
	?FinishAllTestCases@CAutoTestManager@@QAEXW4TTestResult@1@@Z @ 9 NONAME ; void CAutoTestManager::FinishAllTestCases(enum CAutoTestManager::TTestResult)
	?NewL@CAutoTestManager@@SAPAV1@PAVMAutoTestApp@@@Z @ 10 NONAME ; class CAutoTestManager * CAutoTestManager::NewL(class MAutoTestApp *)
	?PreallocateHALBuffer@@YAXXZ @ 11 NONAME ; void PreallocateHALBuffer(void)
	?ProcessCommandL@CTestAppUi@@MAEXH@Z @ 12 NONAME ; void CTestAppUi::ProcessCommandL(int)
	?ReduceRect@CTestAppUi@@IBEXAAVTRect@@@Z @ 13 NONAME ; void CTestAppUi::ReduceRect(class TRect &) const
	?SetTestCaseNumber@CAutoTestManager@@QAEXH@Z @ 14 NONAME ; void CAutoTestManager::SetTestCaseNumber(int)
	?StartAutoTest@CAutoTestManager@@QAEXXZ @ 15 NONAME ; void CAutoTestManager::StartAutoTest(void)
	?CloseAllPanicWindowsL@@YAXXZ @ 16 NONAME ; void CloseAllPanicWindowsL(void)
	??0CTestAppUi@@QAE@PAVCTmsTestStep@@ABVTDesC16@@HHH@Z @ 17 NONAME ; CTestAppUi::CTestAppUi(class CTmsTestStep *, class TDesC16 const &, int, int, int)
	??0CTestCoeAppUi@@QAE@PAVCTmsTestStep@@@Z @ 18 NONAME ; CTestCoeAppUi::CTestCoeAppUi(class CTmsTestStep *)
	?RecordTestResultL@CTmsTestStep@@QAEXXZ @ 19 NONAME ; void CTmsTestStep::RecordTestResultL(void)
	?MultipleResultsForSameID@CTmsTestStep@@QAEXH@Z @ 20 NONAME ; void CTmsTestStep::MultipleResultsForSameID(int)
	??0CTmsTestStep@@QAE@XZ @ 21 NONAME ; CTmsTestStep::CTmsTestStep(void)
	?MQCTest@CTmsTestStep@@QAEXHPBEH@Z @ 22 NONAME ; void CTmsTestStep::MQCTest(int, unsigned char const *, int)
	??1CTmsTestStep@@UAE@XZ @ 23 NONAME ; CTmsTestStep::~CTmsTestStep(void)
	?SetTestStepID@CTmsTestStep@@QAEXABVTDesC16@@@Z @ 24 NONAME ; void CTmsTestStep::SetTestStepID(class TDesC16 const &)
	?MQCTestL@CTmsTestStep@@QAEXHPBEH@Z @ 25 NONAME ; void CTmsTestStep::MQCTestL(int, unsigned char const *, int)
	?CloseTMSGraphicsStep@CTmsTestStep@@QAEXXZ @ 26 NONAME ; void CTmsTestStep::CloseTMSGraphicsStep(void)
	?SetOverallTestStepID@CTmsTestStep@@QAEXABVTDesC16@@@Z @ 27 NONAME ; void CTmsTestStep::SetOverallTestStepID(class TDesC16 const &)

